#include "test.h"

int test_cfunc(int b){
  printf("Hello World\n");
  return b+1;
}

int test_cfunc_name(char* name, int b){
  printf("Hello World %s\n", name);
  return b+1;
}

void return_string_name(char* name, char* nameout){
  strcpy (nameout,"Hello ");
  strcat (nameout, name);
  strcat (nameout," !!");
}

int main(void){
  char name[30]="Maria";
  char nameout[50];
  return_string_name(name,nameout);
  printf("%s\n%s\n", name, nameout);
  return 0;
}
